.. TOAST documentation master file, created by
   sphinx-quickstart on Thu Apr  9 10:07:11 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


TOAST
=============

Contents:

.. toctree::
    :maxdepth: 2

    intro.rst
    changes.rst
    install.rst
    data.rst
    operators.rst
    pipelines.rst
    utils.rst
    nersc.rst
    tutorial.rst
    dev.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
